Test coverage report: frequently.templatetags.frequently_tags

# frequently.templatetags.frequently_tags: 10 total statements, 100.0% covered

Generated: Sat 2013-07-20 15:17 CEST

Source file: /home/tobi/Projects/django-frequently/src/frequently/templatetags/frequently_tags.py

Stats: 8 executed, 0 missed, 2 excluded, 8 ignored

1. `"""Template tags for the ``frequently`` app."""`
2. `from django import template`
3. ``
4. `from ..models import EntryCategory`
5. ``
6. `register = template.Library()`
7. ``
8. ``
9. `@register.inclusion_tag('frequently/partials/category.html')`
10. `def render_category(slug):`
11. `"""Template tag to render a category with all it's entries."""`
12. `try:`
13. `category = EntryCategory.objects.get(slug=slug)`
14. `except EntryCategory.DoesNotExist:`
15. `pass`
16. `else:`
17. `return {'category': category}`
18. `return {}`